@@ -621,12 +621,8 @@ sub compute_program_log($) {
        foreach (@{$self->{_orig_argv}}) {
 	    if (ref($_) eq 'CODE') {
 		$args .= " [ANONYMOUS-CODE]";
-	    } elsif ($_ =~ /\s/) {
-	        # should use String::ShellQuote, but don't want the dpeendency
-		$_ =~ s/\'/'\\\''/g;
-		$args .= " '" . $_ . "'";
 	    } else {
-		$args .= " " . $_;
+		$args .= " " . Fsdb::Support::shell_quote($_);
 	    };
        };
     };
